@@ -1,6 +1,6 @@
 
 
-setMethod('as.character', signature(x='Extent'), 
+setMethod("as.character", signature(x="Extent"), 
 	function(x, ...) {
 		e <- extent(x)
 		paste0("extent(", paste(as.vector(e), collapse=", "), ")")
@@ -8,10 +8,10 @@ setMethod('as.character', signature(x='Extent'),
 )
 
 
-setMethod('as.character', signature(x='Raster'), 
+setMethod("as.character", signature(x="Raster"), 
 	function(x, ...) {
 		e <- extent(x)
-		crs <- crs(x)
+		crs <- proj4string(x)
 		crs <- ifelse(is.na(crs), ", crs=''", paste0(", crs='", crs, "'"))
 		if (nlayers(x) < 2) {
 			paste0("raster(", 
