@@ -7,7 +7,7 @@
 
 
 .makeTextFun <- function(fun) {
-	if (class(fun) != 'character') {
+	if (class(fun)[1] != 'character') {
 		if (is.primitive(fun)) {
 			test <- try(deparse(fun)[[1]], silent=TRUE)
 			if (test == '.Primitive(\"sum\")') { fun <- 'sum' 
@@ -76,7 +76,7 @@
 			} else {
 				test <- try( apply(tstdat, 1, fun, na.rm=na.rm), silent=TRUE)
 			}
-			if (length(test) < length(tstdat) | class(test) == 'try-error') {
+			if (length(test) < length(tstdat) | inherits(test, "try-error")) {
 				stop('cannot forceapply this function')
 			}
 			if (is.matrix(test)) {
@@ -87,10 +87,10 @@
 		} else {
 			if (! missing(na.rm)) {
 				test <- try(fun(tstdat, na.rm=na.rm), silent=TRUE)
-				if (class(test) == 'try-error') {
+				if (inherits(test, "try-error")) {
 					test <- try( apply(tstdat, 1, fun, na.rm=na.rm), silent=TRUE)
 					doapply <- TRUE
-					if (class(test) == 'try-error') {
+					if (inherits(test, "try-error")) {
 						stop("cannot use this function. Perhaps add '...' or 'na.rm' to the function arguments?") 
 					} 
 					if (is.matrix(test)) {
@@ -101,12 +101,12 @@
 				}
 			} else {
 				test <- try(fun(tstdat), silent=TRUE)
-				if (length(test) < length(tstdat) | class(test) == 'try-error') {
+				if (length(test) < length(tstdat) | inherits(test, "try-error")) {
 					doapply <- TRUE
 					makemat <- TRUE	
 					tstdat <- matrix(tstdat, ncol=1)					
 					test <- try( apply(tstdat, 1, fun), silent=TRUE)
-					if (class(test) == 'try-error') {
+					if (inherits(test, "try-error")) {
 						stop("cannot use this function")
 					}
 					if (is.matrix(test)) {
@@ -127,10 +127,10 @@
 			doapply <- TRUE
 			if (! missing(na.rm)) {
 				test <- try( apply(tstdat, 1, fun, na.rm=na.rm), silent=TRUE)
-				if (class(test) == 'try-error') {
+				if (inherits(test, "try-error")) {
 					doapply <- FALSE
 					test <- try(fun(tstdat, na.rm=na.rm), silent=TRUE)
-					if (class(test) == 'try-error') {
+					if (inherits(test, "try-error")) {
 						stop("cannot use this function. Perhaps add '...' or 'na.rm' to the function arguments?") 
 					}
 				} else if (is.matrix(test)) {
@@ -138,10 +138,10 @@
 				}
 			} else {
 				test <- try( apply(tstdat, 1, fun), silent=TRUE)
-				if (class(test) == 'try-error') {
+				if (inherits(test, "try-error")) {
 					doapply <- FALSE
 					test <- try(fun(tstdat), silent=TRUE)
-					if (class(test) == 'try-error') {
+					if (inherits(test, "try-error")) {
 						stop("cannot use this function") 
 					}
 				} else if (is.matrix(test)) {
@@ -183,14 +183,15 @@ function(x, fun, filename='', na.rm, forcefun=FALSE, forceapply=FALSE, ...) {
 	}
 
 	fun <- .makeTextFun(fun)
-	if (class(fun) == 'character') { 
+	if (class(fun)[1] == 'character') { 
 		doapply <- FALSE
 		fun <- .getRowFun(fun)
 	} 
 	
 	filename <- trim(filename)
-
-	if (canProcessInMemory(x, max(nlayers(x), nlayers(out)) * 2)) {
+	
+	estnl <- (nlayers(x) + nlayers(out)) * 2
+	if (canProcessInMemory(x, estnl)) {
 		x <- getValues(x)
 		if (makemat) { 
 			x <- matrix(x, ncol=1) 
@@ -222,7 +223,7 @@ function(x, fun, filename='', na.rm, forcefun=FALSE, forceapply=FALSE, ...) {
 	
 	x <- readStart(x)
 	out <- writeStart(out, filename=filename, ...)
-	tr <- blockSize(out)
+	tr <- blockSize(out, n=estnl)
 	pb <- pbCreate(tr$n, label='calc', ...)			
 
 	if (missing(na.rm)) {
