@@ -3,14 +3,9 @@
 # Version 0.9
 # Licence GPL v3
 
-if (!isGeneric("distance")) {
-	setGeneric("distance", function(x, ...)
-		standardGeneric("distance"))
-}	
 
-
-setMethod('distance', signature(x='RasterLayer'), 
-function(x, filename='', doEdge=TRUE, ...) {
+setMethod('distance', signature(x='RasterLayer', y='missing'), 
+function(x, y, filename='', doEdge=TRUE, ...) {
 	if (doEdge) {
 		r <- boundaries(x, classes=FALSE, type='inner', progress=.progress(...)) 
 		pts <- try(  rasterToPoints(r, fun=function(z){ z>0 } )[,1:2, drop=FALSE] )
@@ -18,7 +13,7 @@ function(x, filename='', doEdge=TRUE, ...) {
 		pts <- try(  rasterToPoints(x)[,1:2, drop=FALSE] )
 	}
 	
-	if (class(pts) == "try-error") {
+	if (inherits(pts, "try-error")) {
 		return( .distanceRows(x, filename=filename, ...) )
 	}
 	if (nrow(pts) == 0) {
@@ -43,7 +38,7 @@ function(x, filename='', doEdge=TRUE, ...) {
 		pbStep(pb)
 		x[] <- 0
 		xy <- xyFromCell(out, i)
-		x[i] <- .Call("distanceToNearestPoint", xy, pts, as.integer(longlat), PACKAGE='raster')
+		x[i] <- .Call('_raster_distanceToNearestPoint', xy, pts, longlat, 6378137.0, 1/298.257223563, PACKAGE='raster')
 		pbStep(pb)
 		out <- setValues(out, x)
 		if (filename != '') {
@@ -67,7 +62,7 @@ function(x, filename='', doEdge=TRUE, ...) {
 		j <- which(is.na(vals))
 		vals[] <- 0
 		if (length(j) > 0) {
-			vals[j] <- .Call("distanceToNearestPoint", xy[j,,drop=FALSE], pts, as.integer(longlat), PACKAGE='raster')
+			vals[j] <- .Call('_raster_distanceToNearestPoint', xy[j,,drop=FALSE], pts, longlat, 6378137.0, 1/298.257223563, PACKAGE='raster')	
 		}
 		out <- writeValues(out, vals, tr$row[i])
 		pbStep(pb) 	
@@ -78,3 +73,22 @@ function(x, filename='', doEdge=TRUE, ...) {
 }
 )
 
+
+setMethod('distance', signature(x='RasterLayer', y='RasterLayer'), 
+function(x, y, ...) {
+	stats::dist(as.matrix(stack(x, y)))
+}
+)
+
+setMethod('distance', signature(x='Spatial', y='Spatial'), 
+function(x, y, ...) {
+	if (!requireNamespace("rgeos")) {
+		stop('This function needs the rgeos package to be available')
+	} 
+	stopifnot(inherits(x, 'SpatialVector'))
+	stopifnot(inherits(y, 'SpatialVector'))	
+	d <- rgeos::gDistance(x, y, byid=TRUE)
+	apply(d, 1, min)
+}
+)
+
