@@ -3,26 +3,29 @@
 # Version 1.0
 # Licence GPL v3
 
-ratify <- function(x, filename='', count=FALSE, ...) {
-	stopifnot(nlayers(x) == 1)
-	if (count) {
-		f <- freq(x, useNA='no')
-		f <- data.frame(f)
-		colnames(f) <- c('ID', 'COUNT')
-	} else {
-		f <- data.frame(ID=unique(x))
-	}
-	x@data@isfactor <- TRUE
-	x@data@attributes <- list(f)
-	if (filename != '') {
-		x <- writeRaster(x, filename, ...)
-		# only native format stores this, hence re-assign these:
-		x@data@isfactor <- TRUE
-		x@data@attributes <- list(f)	
-	}
-	return(x)
-}
+if (!isGeneric("ratify")) {setGeneric("ratify", function(x, ...)		standardGeneric("ratify"))}	
 
+setMethod("ratify", signature(x="Raster"), 
+	function(x, filename="", count=FALSE, ...) {
+		stopifnot(nlayers(x) == 1)
+		if (count) {
+			f <- freq(x, useNA='no')
+			f <- data.frame(f)
+			colnames(f) <- c('ID', 'COUNT')
+		} else {
+			f <- data.frame(ID=unique(x))
+		}
+		x@data@isfactor <- TRUE
+		x@data@attributes <- list(f)
+		if (filename != '') {
+			x <- writeRaster(x, filename, ...)
+			# only native format stores this, hence re-assign these:
+			x@data@isfactor <- TRUE
+			x@data@attributes <- list(f)	
+		}
+		return(x)
+	}
+)
 
 .unweightRAT <- function(rat, fun='mean') {
 
@@ -93,15 +96,16 @@ deratify <- function(x, att=NULL, layer=1, complete=FALSE, drop=TRUE, fun='mean'
 			levels(x) <- .unweightRAT(RAT, fun)
 		}
 	} else if (NCOL(RAT) == 1) {
-		warning('this layer already has a single factor level (use "complete=TRUE" to remove it)')
-		return(x)
+		if (complete) {
+			x@data@isfactor <- FALSE
+			x@data@attributes <- list()
+			return(x)
+		} else {
+			warning('this layer already has a single factor level (use "complete=TRUE" to remove it)')
+			return(x)
+		}
 	}
 	
-	if (complete) {
-		x@data@isfactor <- FALSE
-		x@data@attributes <- list()
-		return(x)
-	}
 	
 	nms <- colnames(RAT)
 	if (!is.null(att)) {
